==> bash-config_23.03.01.tar.xz: mx-bashrc-config/translations/bash-config_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AliasTab</name>
    <message>
        <location filename="../aliastab.ui" line="71"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../aliastab.ui" line="82"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>OtherTab</name>
    <message>
        <location filename="../othertab.ui" line="35"/>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="41"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="63"/>
        <source>Infinite</source>
        <translation>Infinito</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="75"/>
        <source>Executable Paths</source>
        <translation>Caminhos de Acesso para os Executáveis</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="84"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="97"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="108"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>PromptTab</name>
    <message>
        <location filename="../prompttab_fix.ui" line="44"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Altera a exibição das mensagens dos comando.&lt;/p&gt;&lt;p&gt;Padrão - Utilize o prompt de comando que você tinha antes.&lt;/p&gt;&lt;p&gt;Prompt Elaborado - Utilize o programa utilitário Fancy Prompt do MX&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="152"/>
        <source>Make The Larger Prompts Smaller</source>
        <translation>Reduzir o Tamanho das Mensagens Grandes</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="159"/>
        <source>Muted Colors</source>
        <translation>Cores Suaves</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="166"/>
        <source>Disable Unicode</source>
        <translation>Desativar do Código Unicode</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="173"/>
        <source>Use Double Lines</source>
        <translation>Utilizar Linhas Duplas</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="180"/>
        <source>Use Bold Lines</source>
        <translation>Utilizar Linhas em Negrito</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="187"/>
        <source>No Colors(Overrides All Other Color Options)</source>
        <translation>Sem Cores (Substitui Todas as Outras Opções de Cores)</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="194"/>
        <source>Use Parentheses Instead Of Square Brackets</source>
        <translation>Utilizar os Parênteses ( ) em Vez dos Colchetes [ ]</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="201"/>
        <source>Make the Larger Prompts Smaller Elsewhere</source>
        <translation>Reduzir o Tamanho das Mensagens Grandes em Outros Lugares</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="225"/>
        <source>Time Format</source>
        <translation>Formato da Hora</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="267"/>
        <source>Date Format</source>
        <translation>Formato da Data</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="315"/>
        <source>Right Margin</source>
        <translation>Margem Direita</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="351"/>
        <source>Extra Newlines Before Prompt</source>
        <translation>Adicionar Novas Linhas Antes do Prompt</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="380"/>
        <source>Prompt Text</source>
        <translation>Texto do Prompt</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="409"/>
        <source>Title Text</source>
        <translation>Texto do Título</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="429"/>
        <source>Remove all newlines</source>
        <translation>Remover Todas as Novas Linhas</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="456"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="478"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="501"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="518"/>
        <source>Up</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="535"/>
        <source>Down</source>
        <translation>Abaixo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../prompttab.cpp" line="543"/>
        <source>Foreground Color</source>
        <translation>Cor do Primeiro Plano</translation>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="544"/>
        <source>Background Color</source>
        <translation>Cor do Plano de Fundo</translation>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="545"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window_fix.ui" line="35"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="46"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="85"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Aplicar as Alterações.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="88"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="99"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fechar o aplicativo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="102"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="48"/>
        <source>An easy way to configure your ~/.bashrc and bash prompt</source>
        <translation>Uma maneira fácil de configurar o arquivo ~/.bashrc e o seu prompt do interpretador de comandos &apos;bash&apos;</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="260"/>
        <location filename="../window.cpp" line="264"/>
        <location filename="../window.cpp" line="268"/>
        <source>Bash Config</source>
        <translation>Configurações do Bash</translation>
    </message>
</context>
</TS>

==> bash-config_24.04.02.tar.xz: mx-bashrc-config/translations/bash-config_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AliasTab</name>
    <message>
        <location filename="../aliastab.ui" line="71"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../aliastab.ui" line="82"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>OtherTab</name>
    <message>
        <location filename="../othertab.ui" line="35"/>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="41"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="63"/>
        <source>Infinite</source>
        <translation>Infinito</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="75"/>
        <source>Executable Paths</source>
        <translation>Caminhos de Acesso para os Executáveis</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="84"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="97"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../othertab.ui" line="108"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>PromptTab</name>
    <message>
        <location filename="../prompttab_fix.ui" line="44"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Change what gives you your prompt.&lt;/p&gt;&lt;p&gt;Default - Use what prompt you had before.&lt;/p&gt;&lt;p&gt;Fancy Prompt - Uses the MX Fancy Prompt utility&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Altera a exibição das mensagens dos comando.&lt;/p&gt;&lt;p&gt;Padrão - Utilize o prompt de comando que você tinha antes.&lt;/p&gt;&lt;p&gt;Prompt Elaborado - Utilize o programa utilitário Fancy Prompt do MX&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="152"/>
        <source>Make The Larger Prompts Smaller</source>
        <translation>Reduzir o Tamanho das Mensagens Grandes</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="159"/>
        <source>Muted Colors</source>
        <translation>Cores Suaves</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="166"/>
        <source>Disable Unicode</source>
        <translation>Desativar do Código Unicode</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="173"/>
        <source>Use Double Lines</source>
        <translation>Utilizar Linhas Duplas</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="180"/>
        <source>Use Bold Lines</source>
        <translation>Utilizar Linhas em Negrito</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="187"/>
        <source>No Colors(Overrides All Other Color Options)</source>
        <translation>Sem Cores (Substitui Todas as Outras Opções de Cores)</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="194"/>
        <source>Use Parentheses Instead Of Square Brackets</source>
        <translation>Utilizar os Parênteses ( ) em Vez dos Colchetes [ ]</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="201"/>
        <source>Make the Larger Prompts Smaller Elsewhere</source>
        <translation>Reduzir o Tamanho das Mensagens Grandes em Outros Lugares</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="225"/>
        <source>Time Format</source>
        <translation>Formato da Hora</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="267"/>
        <source>Date Format</source>
        <translation>Formato da Data</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="315"/>
        <source>Right Margin</source>
        <translation>Margem Direita</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="351"/>
        <source>Extra Newlines Before Prompt</source>
        <translation>Adicionar Novas Linhas Antes do Prompt</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="380"/>
        <source>Prompt Text</source>
        <translation>Texto do Prompt</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="409"/>
        <source>Title Text</source>
        <translation>Texto do Título</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="429"/>
        <source>Remove all newlines</source>
        <translation>Remover Todas as Novas Linhas</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="456"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="478"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="501"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="518"/>
        <source>Up</source>
        <translation>Acima</translation>
    </message>
    <message>
        <location filename="../prompttab_fix.ui" line="535"/>
        <source>Down</source>
        <translation>Abaixo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../prompttab.cpp" line="546"/>
        <source>Foreground Color</source>
        <translation>Cor do Primeiro Plano</translation>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="547"/>
        <source>Background Color</source>
        <translation>Cor do Plano de Fundo</translation>
    </message>
    <message>
        <location filename="../prompttab.cpp" line="548"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window_fix.ui" line="35"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="46"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="85"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Applies Changes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Aplicar as Alterações.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="88"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="99"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Closes the application.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fechar o aplicativo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_fix.ui" line="102"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="48"/>
        <source>An easy way to configure your ~/.bashrc and bash prompt</source>
        <translation>Uma maneira fácil de configurar o arquivo ~/.bashrc e o seu prompt do interpretador de comandos ‘bash’</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="260"/>
        <location filename="../window.cpp" line="264"/>
        <location filename="../window.cpp" line="268"/>
        <source>Bash Config</source>
        <translation>Configurações do Bash</translation>
    </message>
</context>
</TS>
